@@ -11,6 +11,11 @@
 #' @param author Name indicated in the report
 #' @param title Title of the report
 #' @description Generate a docx, xlsx, or pdf report.\cr
+#' In the xlsx report, the observed compactness is simply the ratio of the number 
+#' of mineralized pixels to the number of total pixels.\cr
+#' The corrected modelled compactness is the compactness if the bone had the 
+#' same number of pixels in the centre as on the periphery So it's a compactness 
+#' that corrects for the shape of the bone.
 #' @family BoneProfileR
 #' @examples
 #' \dontrun{
@@ -24,19 +29,30 @@
 #'  bone <- BP_DetectCenters(bone=bone, analysis="logistic")
 #'  bone <- BP_EstimateCompactness(bone, analysis="logistic")
 #'  bone <- BP_FitMLCompactness(bone, analysis="logistic")
-#'  fittedpar <- BP_GetFittedParameters(bone, analysis="logistic")
+#'  fittedpar <- BP_GetFittedParameters(bone, analysis="logistic", 
+#'                                      ML=TRUE, return.all = FALSE)[, "mean"]
 #'  bone <- BP_DuplicateAnalysis(bone, from="logistic", to="flexit")
 #'  bone <- BP_FitMLCompactness(bone, 
 #'                 fitted.parameters=c(fittedpar, K1=1, K2=1), 
 #'                 fixed.parameters=NULL, analysis="flexit")
-#'  compare_AIC(Logistic=BP_GetFittedParameters(bone, analysis="logistic", alloptim=TRUE), 
-#'              Flexit=BP_GetFittedParameters(bone, analysis="flexit", alloptim=TRUE))
+#'  compare_AIC(Logistic=BP_GetFittedParameters(bone, analysis="logistic", 
+#'                                              ML=TRUE, return.all = TRUE), 
+#'              Flexit=BP_GetFittedParameters(bone, analysis="flexit", 
+#'                                            ML=TRUE, return.all = TRUE))
 #'  bone <- BP_FitMLRadialCompactness(bone, analysis="logistic")
 #'  # Test using the change of orientation using default.angle from BP_EstimateCompactness():
 #'  bone <- BP_DuplicateAnalysis(bone, from="logistic", to="logistic_rotation_pi")
 #'  # With a pi rotation, the top moves to the bottom and the left moves to the right
 #'  bone <- BP_EstimateCompactness(bone, rotation.angle=pi, analysis="logistic_rotation_pi")
 #'  bone <- BP_FitMLRadialCompactness(bone, analysis="logistic_rotation_pi")
+#'  # Periodic analysis
+#'  par <- BP_GetFittedParameters(bone, analysis="logistic", ML=TRUE, return.all = FALSE)[, "mean"]
+#'  options(mc.cores=parallel::detectCores())
+#'  bone <- BP_FitMLPeriodicCompactness(bone, analysis="logistic", control.optim=list(trace=2), 
+#'                                      fitted.parameters=c(par, PSin=0.001, PCos=0.001, 
+#'                                      SSin=0.001, SCos=0.001, MinSin=0.001, MinCos=0.001, 
+#'                                      MaxSin=0.001, MaxCos=0.001), replicates.CI=2000)
+#'                                      
 #'  BP_Report(bone=bone, 
 #'            analysis=1,
 #'            docx=NULL, 
@@ -64,15 +80,16 @@
 #' @export
 
 
-BP_Report <- function(bone=stop("A bone section must be provided"), 
+BP_Report <- function(bone=stop("A bone section must be provided")              , 
                       control.plot=list(message=NULL, show.centers=TRUE, 
                                         show.colors=TRUE, show.grid=TRUE, 
-                                        CI="ML", show.legend=TRUE), 
-                      analysis=1, 
-                      docx=file.path(getwd(), "report.docx"), 
-                      pdf=file.path(getwd(), "report.pdf"), 
-                      xlsx=file.path(getwd(), "report.xlsx"), 
-                      author=NULL, title=attributes(bone)$name) {
+                                        CI="ML", show.legend=TRUE)              , 
+                      analysis=1                                                , 
+                      docx=file.path(getwd(), "report.docx")                    , 
+                      pdf=file.path(getwd(), "report.pdf")                      , 
+                      xlsx=file.path(getwd(), "report.xlsx")                    , 
+                      author=NULL                                               , 
+                      title=attributes(bone)$name                               ) {
   
   # control.plot=list(message=NULL, show.centers=TRUE,  show.colors=TRUE, show.grid=TRUE, CI="ML", show.legend=TRUE); analysis=1; pdf=NULL; docx=file.path(getwd(), "report.docx"); xlsx=file.path(getwd(), "report.xlsx"); author=NULL; title=attributes(bone)$name
   
@@ -89,12 +106,15 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
     }
   
   if (is.character(analysis) & (all(analysis != names(out)))) {
-    stop("The analysis does no exist.")
+    stop(paste("The analysis", analysis, "does not exit. Check your data."))
   }
   
   texte <- NULL
   
   date <- out[[analysis]]$timestamp
+  compactness.synthesis <- RM_get(x=bone, RMname=analysis, valuename = "compactness.synthesis")
+  m <- compactness.synthesis$mineralized
+  nm <- compactness.synthesis$unmineralize
   
   if (!is.null(pdf)) {
     control.output.pdf=list(Title=title, 
@@ -155,9 +175,30 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
       texte.pdf <- c(texte.pdf, "")
     }
     
+    out1 <- RM_get(x=bone, RMname=analysis, valuename = "optimPeriodic")
+    
+    if (!is.null(out1)) {
+
+      texte.pdf <- c(texte.pdf, "## Periodic model of compactness")
+      texte.pdf <- c(texte.pdf, "")
+      texte.pdf <- c(texte.pdf,
+                      "```{r echo=FALSE}" ,
+                      paste0("do.call(getFromNamespace('plot.BoneProfileR', ns='BoneProfileR'),
+                          modifyList(control.plot, list(x=bone, type='periodic', analysis='", analysis,"', parameter.name='compactness', col=rainbow(128))))"),
+                      "```")
+      texte.pdf <- c(texte.pdf, "")
+      texte.pdf <- c(texte.pdf, "### Fitted parameters of periodic model of compactness")
+      texte.pdf <- c(texte.pdf, "")
+      texte.pdf <- c(texte.pdf, knitr::kable(cbind(Mean=out1$par, SE=out1$SE)))
+      texte.pdf <- c(texte.pdf, "")
+      texte.pdf <- c(texte.pdf, "### Modeled compactness")
+      texte.pdf <- c(texte.pdf, "")
+      texte.pdf <- c(texte.pdf, knitr::kable(out1$GlobalCompactness))
+      texte.pdf <- c(texte.pdf, "")
+    }
     
     texte.pdf <- c(texte.pdf, "", 
-                   "### This software is provided by [Marc Girondot](https://hebergement.universite-paris-saclay.fr/marcgirondot/), Ecologie, Syst\u00E9matique, Evolution, CNRS, Universit\u00E9 Paris Saclay, AgroParisTech.")
+                   "### This software is provided by [Marc Girondot](https://hebergement.universite-paris-saclay.fr/marcgirondot/), Ecologie, Soci\u00E9t\u00E9, Evolution, CNRS, Universit\u00E9 Paris Saclay, AgroParisTech.")
     
     texte.pdf <- iconv(texte.pdf, from = "", to="UTF-8")
     tmp <- tempdir()
@@ -174,7 +215,9 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
     )
     
   }
+  
   if (!is.null(docx)) {
+    
     control.output.docx=list(Title=title, 
                              Author=author, 
                              Date=date, 
@@ -227,14 +270,42 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
                       paste0("do.call(getFromNamespace('plot.BoneProfileR', ns='BoneProfileR'), 
                           modifyList(control.plot, list(x=bone, type='radial', analysis='", analysis,"')))"),
                       "```")
+      
+      texte.docx <- c(texte.docx, "")
+      
+      texte.docx <- c(texte.docx, knitr::kable(cbind(Mean=out1$par, SE=out1$SE)))
+      
       texte.docx <- c(texte.docx, "")
       
       texte.docx <- c(texte.docx, knitr::kable(out1$summary.table)) 
       texte.docx <- c(texte.docx, "")
     }
     
+    out1 <- RM_get(x=bone, RMname=analysis, valuename = "optimPeriodic")
+    
+    if (!is.null(out1)) {
+      
+      texte.docx <- c(texte.docx, "## Periodic model of compactness")
+      
+      texte.docx <- c(texte.docx, 
+                      "```{r echo=FALSE}" , 
+                      paste0("do.call(getFromNamespace('plot.BoneProfileR', ns='BoneProfileR'), 
+                          modifyList(control.plot, list(x=bone, type='periodic', analysis='", analysis,"', parameter.name='compactness', col=rainbow(128))))"),
+                      "```")
+      texte.docx <- c(texte.docx, "")
+      texte.docx <- c(texte.docx, "### Fitted parameters of periodic model of compactness")
+      texte.docx <- c(texte.docx, "")
+      texte.docx <- c(texte.docx, knitr::kable(cbind(Mean=out1$par, SE=out1$SE)))
+      texte.docx <- c(texte.docx, "")
+      texte.docx <- c(texte.docx, "### Modeled compactness")
+      texte.docx <- c(texte.docx, "")
+      texte.docx <- c(texte.docx, knitr::kable(out1$GlobalCompactness))
+      texte.docx <- c(texte.docx, "")
+      
+    }
+    
     texte.docx <- c(texte.docx, "", 
-                    "### This software is provided by [Marc Girondot](https://hebergement.universite-paris-saclay.fr/marcgirondot/), Ecologie, Syst\u00E9matique, Evolution, CNRS, Universit\u00E9 Paris Saclay, AgroParisTech.")
+                    "### This software is provided by [Marc Girondot](https://hebergement.universite-paris-saclay.fr/marcgirondot/), Ecologie, Soci\u00E9t\u00E9, Evolution, CNRS, Universit\u00E9 Paris Saclay, AgroParisTech.")
     
     texte.docx <- iconv(texte.docx, from = "", to="UTF-8")
  
@@ -273,9 +344,14 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
       wb=wb,
       sheetName="Radial")
     
+    openxlsx::addWorksheet(
+      wb=wb,
+      sheetName="Periodic")
+    
     out1 <- RM_get(x=bone, RMname=analysis, valuename = "optim")
     
     if (!is.null(out1)) {
+      
       openxlsx::writeData(
         wb=wb,
         sheet="Global",
@@ -310,64 +386,176 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
         x=RM_get(x=bone, RMname = analysis, valuename = "global.compactness"),
         startCol = 2,
         startRow = 4)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="ML 2.5%",
+        startCol = 2,
+        startRow = 5)
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="ML 50%",
+        startCol = 3,
+        startRow = 5)
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="ML 95%",
+        startCol = 4,
+        startRow = 5)
    
       openxlsx::writeData(
         wb=wb,
         sheet="Global",
-        x="Modeled compactness by ML (2.5%, 50%, 97.5%)",
-        startCol = 1,
-        startRow = 5)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "optim")$quantiles["2.5%", ]),
-        startCol = 2,
-        startRow = 5)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "optim")$quantiles["50%", ]),
-        startCol = 3,
-        startRow = 5)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "optim")$quantiles["97.5%", ]),
-        startCol = 4,
-        startRow = 5)
-      
-      if (!is.null(RM_get(x=bone, RMname = analysis, valuename = "mcmc"))) {
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Global",
-        x="Modeled compactness by MCMC (2.5%, 50%, 97.5%)",
+        x="Modeled compactness",
         startCol = 1,
         startRow = 6)
       
       openxlsx::writeData(
         wb=wb,
         sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "mcmc")$quantiles["2.5%", ]),
+        x=sum(((m+nm)*out1$quantiles["2.5%", ]))/sum((m+nm)),
         startCol = 2,
         startRow = 6)
       
       openxlsx::writeData(
         wb=wb,
         sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "mcmc")$quantiles["50%", ]),
+        x=sum(((m+nm)*out1$quantiles["50%", ]))/sum((m+nm)),
         startCol = 3,
         startRow = 6)
       
       openxlsx::writeData(
         wb=wb,
         sheet="Global",
-        x=mean(RM_get(x=bone, RMname = analysis, valuename = "mcmc")$quantiles["97.5%", ]),
+        x=sum(((m+nm)*out1$quantiles["97.5%", ]))/sum((m+nm)),
         startCol = 4,
         startRow = 6)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="Linear compactnes",
+        startCol = 1,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(out1$quantiles["2.5%", ]),
+        startCol = 2,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(out1$quantiles["50%", ]),
+        startCol = 3,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(out1$quantiles["97.5%", ]),
+        startCol = 4,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="The objective of estimation of modeled compacity is to verify that the fitted model represents well the observed compacity.",
+        startCol = 1,
+        startRow = 8)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x="The linear compacity represents the integration under the compacity curve then without taking into account that surface at the center is smaller than surface at periphery. The biological meaning of the linear compacity is not clear.",
+        startCol = 1,
+        startRow = 9)
+      
+
+      outmcmc <- RM_get(x=bone, RMname=analysis, valuename = "mcmc")
+      
+      if (!is.null(outmcmc)) {
+        
+        openxlsx::writeData(
+          wb=wb,
+          sheet="Global",
+          x="MCMC 2.5%",
+          startCol = 5,
+          startRow = 5)
+        openxlsx::writeData(
+          wb=wb,
+          sheet="Global",
+          x="MCMC 50%",
+          startCol = 6,
+          startRow = 5)
+        openxlsx::writeData(
+          wb=wb,
+          sheet="Global",
+          x="MCMC 95%",
+          startCol = 7,
+          startRow = 5)
+        
+      
+      # openxlsx::writeData(
+      #   wb=wb,
+      #   sheet="Global",
+      #   x="Modeled compactness by MCMC (2.5%, 50%, 97.5%)",
+      #   startCol = 1,
+      #   startRow = 6)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=sum(((m+nm)*outmcmc$quantiles["2.5%", ]))/sum((m+nm)),
+        startCol = 5,
+        startRow = 6)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=sum(((m+nm)*outmcmc$quantiles["50%", ]))/sum((m+nm)),
+        startCol = 6,
+        startRow = 6)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=sum(((m+nm)*outmcmc$quantiles["97.5%", ]))/sum((m+nm)),
+        startCol = 7,
+        startRow = 6)
+      
+      # openxlsx::writeData(
+      #   wb=wb,
+      #   sheet="Global",
+      #   x="Modeled corrected compactness by MCMC (2.5%, 50%, 97.5%)",
+      #   startCol = 1,
+      #   startRow = 8)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(outmcmc$quantiles["2.5%", ]),
+        startCol = 5,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(outmcmc$quantiles["50%", ]),
+        startCol = 6,
+        startRow = 7)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Global",
+        x=mean(outmcmc$quantiles["97.5%", ]),
+        startCol = 7,
+        startRow = 7)
       }
       
       openxlsx::writeData(
@@ -442,64 +630,119 @@ BP_Report <- function(bone=stop("A bone section must be provided"),
         wb=wb,
         sheet="Radial",
         x=out1$synthesis,
+        startCol = 1,
+        startRow = 20)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="TRC",
+        startCol = 9,
+        startRow = 20)
+
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="Observed compacteness",
+        startCol = 10,
+        startRow = 20)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="Linearized observed compactness",
+        startCol = 11,
+        startRow = 20)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="Modeled compactness",
+        startCol = 12,
+        startRow = 20)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="Linearized modeled compactness",
+        startCol = 13,
+        startRow = 20)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="The 'Observed compactness' is the observed compactness of the portion.",
+        startCol = 1,
+        startRow = 12)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="The 'Linearized observed compactness' is the observed compactness of the portion weighted to be linearized.",
+        startCol = 1,
+        startRow = 13)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="The 'Modeled compactness' is the modeled compactness.",
+        startCol = 1,
+        startRow = 14)
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Radial",
+        x="The 'Linearized modeled compactness' is the modeled compactness of the portion weighted to be linearized.",
+        startCol = 1,
+        startRow = 15)
+    }
+    
+    out1 <- RM_get(x=bone, RMname=analysis, valuename = "optimPeriodic")
+    
+    if (!is.null(out1)) {
+      
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Periodic",
+        x="Periodic model of compactness",
+        startCol = 1,
+        startRow = 1)
+
+      openxlsx::writeData(
+        wb=wb,
+        sheet="Periodic",
+        x=rbind(Mean=out1$par, SE=out1$SE),
         startCol = 2,
-        startRow = 13)
+        startRow = 3)
       
       openxlsx::writeData(
         wb=wb,
-        sheet="Radial",
-        x="Angle",
+        sheet="Periodic",
+        x="Mean",
         startCol = 1,
-        startRow = 13)
+        startRow = 4)
       
       openxlsx::writeData(
         wb=wb,
-        sheet="Radial",
-        x=out1$angles,
+        sheet="Periodic",
+        x="SE",
         startCol = 1,
-        startRow = 14)
+        startRow = 5)
       
       openxlsx::writeData(
         wb=wb,
-        sheet="Radial",
-        x="Radial modeled compactness",
-        startCol = 10,
-        startRow = 13)
+        sheet="Periodic",
+        x=out1$GlobalCompactness,
+        startCol = 2,
+        startRow = 8)
       
       openxlsx::writeData(
         wb=wb,
-        sheet="Radial",
-        x=out1$radial.modeled.compactness,
-        startCol = 10,
-        startRow = 14)
+        sheet="Periodic",
+        x=rownames(out1$GlobalCompactness),
+        startCol = 1,
+        startRow = 9)
       
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Radial",
-        x="Radial observed modeled compactness",
-        startCol = 11,
-        startRow = 13)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Radial",
-        x=out1$observed.modeled.compactness,
-        startCol = 11,
-        startRow = 14)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Radial",
-        x="Radial observed compactness",
-        startCol = 12,
-        startRow = 13)
-      
-      openxlsx::writeData(
-        wb=wb,
-        sheet="Radial",
-        x=out1$observed.compactness,
-        startCol = 12,
-        startRow = 14)
     }
     
     openxlsx::saveWorkbook(wb, file = xlsx, overwrite = TRUE)
